Apply Soft Projection to Data and Design
Source:R/soft_subspace_projection.R
apply_soft_projection.RdApplies the soft projection to both the data matrix Y and design matrix X. Both must be projected to avoid bias in coefficient estimates.
Arguments
- proj
A soft_projection object from
soft_projection().- Y
Data matrix (time x voxels).
- X
Design matrix (time x predictors).