Reconstructs the fmri_frame from the job's dataset_spec. For
file-backed specs this is where data first becomes addressable (still lazily,
through the frame's NIfTI array source).
Arguments
- job
An fmri_job.
Reconstructs the fmri_frame from the job's dataset_spec. For
file-backed specs this is where data first becomes addressable (still lazily,
through the frame's NIfTI array source).
An fmri_job.