Realizes the dataset, assembles the model, fits it with the template's control options (and engine, if any), and applies the template's reducer.
Arguments
- job
An fmri_job.
- progress
Logical; show a fitting progress bar.
Realizes the dataset, assembles the model, fits it with the template's control options (and engine, if any), and applies the template's reducer.
An fmri_job.
Logical; show a fitting progress bar.