Reconstructs the fmri_dataset from the job's dataset_spec. For
file-backed specs this is where data first becomes addressable (still lazily,
per the dataset backend).
Arguments
- job
An fmri_job.
See also
build_model(), run()
Reconstructs the fmri_dataset from the job's dataset_spec. For
file-backed specs this is where data first becomes addressable (still lazily,
per the dataset backend).
An fmri_job.
build_model(), run()